![full test run](https://github.com/siheming/mspypeline/workflows/full%20test%20run/badge.svg?branch=master)
[![Coverage](https://codecov.io/gh/siheming/mspypeline/branch/master/graph/badge.svg?flag=full-test-run)](https://codecov.io/gh/siheming/mspypeline/branch/master)

![basic test run](https://github.com/siheming/mspypeline/workflows/basic%20test%20run/badge.svg?branch=develop)
[![Coverage](https://codecov.io/gh/siheming/mspypeline/branch/develop/graph/badge.svg?flag=basic-test-run)](https://codecov.io/gh/siheming/mspypeline/branch/develop)

[![Documentation Status](https://readthedocs.org/projects/mspypeline/badge/?version=latest)](https://mspypeline.readthedocs.io/en/latest/?badge=latest)

# README
This pipeline can be used to analyze the results of a MaxQuant analysis.  
To use this package please refer to [the docs](https://mspypeline.readthedocs.io/en/latest/index.html).  

The sources can be found at [PyPI](https://pypi.org/project/mspypeline/) or
[conda](https://anaconda.org/siheming/mspypeline).

# Contribute
If you want to contribute to the project please create a pull request on the develop branch.

# Support
If you encounter a bug or want to request a feature open an issue on github.
